@@ -1,10 +1,11 @@
 '''
+[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)
 [![GitHub](https://img.shields.io/github/license/pepperize/cdk-github?style=flat-square)](https://github.com/pepperize/cdk-github/blob/main/LICENSE)
 [![npm (scoped)](https://img.shields.io/npm/v/@pepperize/cdk-github?style=flat-square)](https://www.npmjs.com/package/@pepperize/cdk-github)
 [![PyPI](https://img.shields.io/pypi/v/pepperize.cdk-github?style=flat-square)](https://pypi.org/project/pepperize.cdk-github/)
 [![Nuget](https://img.shields.io/nuget/v/Pepperize.CDK.Github?style=flat-square)](https://www.nuget.org/packages/Pepperize.CDK.Github/)
 [![Sonatype Nexus (Releases)](https://img.shields.io/nexus/r/com.pepperize/cdk-github?server=https%3A%2F%2Fs01.oss.sonatype.org%2F&style=flat-square)](https://s01.oss.sonatype.org/content/repositories/releases/com/pepperize/cdk-github/)
-[![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/pepperize/cdk-github/release/main?label=release&style=flat-square)](https://github.com/pepperize/cdk-github/actions/workflows/release.yml)
+[![GitHub Workflow Status (branch)](https://img.shields.io/github/actions/workflow/status/pepperize/cdk-github/release.yml?branch=main&label=release&style=flat-square)](https://github.com/pepperize/cdk-github/actions/workflows/release.yml)
 [![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/pepperize/cdk-github?sort=semver&style=flat-square)](https://github.com/pepperize/cdk-github/releases)
 [![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod&style=flat-square)](https://gitpod.io/#https://github.com/pepperize/cdk-github)
 
@@ -14,6 +15,8 @@ Manage GitHub resources like repositories, teams, members, integrations and work
 
 > You configure the endpoint, method and parameters documented by [@octokit/rest](https://octokit.github.io/rest.js/v19) and AWS CloudFormation runs them anytime you create, update (if you changed the custom resource), or delete stacks. When CloudFormation sends a lifecycle event notification, then your custom resource sends the request to the [GitHub REST API](https://docs.github.com/en/rest).
 
+[![View on Construct Hub](https://constructs.dev/badge?package=%40pepperize%2Fcdk-github)](https://constructs.dev/packages/@pepperize/cdk-github)
+
 ## Install
 
 <details><summary><strong>TypeScript</strong></summary>
@@ -96,7 +99,7 @@ yarn build
 6. Import your secret
 
    ```python
-   const secret = secrets_manager.Secret.fromSecretNameV2(stack, "Auth", "cdk-github/test");
+   const secret = secrets_manager.Secret.fromSecretNameV2(stack, "Auth", "cdk-github/github-token");
    ```
 7. Configure GitHub App authenticate as an installation
 
@@ -153,7 +156,7 @@ Lookup the secret in your AWS CDK app:
 
 ```python
 // 👇Lookup your secret containing the AuthOptions
-const secret = secrets_manager.Secret.fromSecretNameV2(stack, "Auth", "cdk-github/test");
+const secret = secrets_manager.Secret.fromSecretNameV2(stack, "Auth", "cdk-github/github-token");
 // 👇This will send the secret arn to the custom resource handler
 const authOptions = AuthOptions.appAuth(secret);
 ```
@@ -176,7 +179,7 @@ Just add your PAT to an SSM StringParameter
 
 ```python
 // 👇Lookup your parameter containing the TOKEN
-const parameter = ssm.StringParameter.fromStringParameterName(stack, "Auth", "cdk-github/test");
+const parameter = ssm.StringParameter.fromStringParameterName(stack, "Auth", "cdk-github/github-token");
 // 👇This will send the parameter arn to the custom resource handler
 const authOptions = AuthOptions.tokenAuth(parameter);
 ```
@@ -190,14 +193,16 @@ const authOptions = AuthOptions.tokenAuth(parameter);
 const authOptions = AuthOptions.unauthenticated();
 ```
 
-## Example
+## Manage a GitHub Repository - Example
+
+[![Manage a GitHub Repository as custom CFN resource](https://raw.githubusercontent.com/pepperize/cdk-github/main/cloudformation-stack-github-custom-resource.png)](https://github.com/pepperize/cdk-github/blob/main/src/integ.default.ts)
 
 [@octokit/plugin-rest-endpoint-methods](https://github.com/octokit/plugin-rest-endpoint-methods.js/#usage)
 
 ```python
-const secret = secrets_manager.Secret.fromSecretNameV2(stack, "Auth", "cdk-github/test");
+const auth = secrets_manager.Secret.fromSecretNameV2(stack, "Auth", "cdk-github/github-token");
 
-new GithubCustomResource(stack, "GithubRepo", {
+const repo = new GithubCustomResource(stack, "GithubRepo", {
   onCreate: {
     // https://octokit.github.io/rest.js/v19/#repos-create-in-org
     endpoint: "repos",
@@ -231,9 +236,95 @@ new GithubCustomResource(stack, "GithubRepo", {
     },
     outputPaths: [],
   },
-  authOptions: AuthOptions.appAuth(secret),
+  authOptions: AuthOptions.appAuth(auth),
+});
+
+// 👇 This will return the created repository id as a CDK Token
+repo.getAtt("id");
+```
+
+## Manage GitHub Actions Secrets
+
+### Environment Secret
+
+Manages an environment secret. Will fetch the source AWS SecretsManager secret and encrypt it to store in GitHub.
+
+```python
+// 👇The GitHub API authentication secret
+const auth = secrets_manager.Secret.fromSecretNameV2(scope, "Auth", "cdk-github/github-token");
+
+// 👇The AWS SecretsManager Secret to configure as GitHub Action secret.
+const secret = secrets_manager.Secret.fromSecretNameV2(scope, "Secret", "any-secret/example");
+
+new GithubActionsSecretEnvironment(scope, "GithubRepo", {
+  // 👇The repository id, which you may lookup from the page source or via a custom resource
+  repositoryId: "558989134",
+  environmentName: "production",
+  // 👇The name of the created GitHub secret
+  secretName: "example",
+  // 👇The source AWS SecretsManager secret and JSON field to use
+  source: GithubActionsSecret.fromSecretsManager(secret, "some-json-field"),
+  authOptions: AuthOptions.appAuth(auth),
+  // 👇Whether to delete or retain the GitHub secret on resource removal
+  removalPolicy: RemovalPolicy.DESTROY,
 });
 ```
+
+> You may retrieve the `repository_id` from the GitHub Repository page source's meta tag i.e. `<meta name="octolytics-dimension-repository_id" content="558989134">` or from another `GithubCustomResource` via `getAtt()`.
+
+See [GitHub Developer Guide](https://docs.github.com/de/rest/actions/secrets#create-or-update-an-environment-secret), [API Reference](https://github.com/pepperize/cdk-github/blob/main/API.md)
+
+### Organization Secret
+
+Manage an GitHib Actions organization secret. Will fetch the source AWS SecretsManager secret and encrypt it to store in GitHub.
+
+```python
+// 👇The GitHub API authentication secret
+const auth = secrets_manager.Secret.fromSecretNameV2(scope, "Auth", "cdk-github/github-token");
+
+// 👇The AWS SecretsManager Secret to configure as GitHub Action secret.
+const secret = secrets_manager.Secret.fromSecretNameV2(scope, "Secret", "any-secret/example");
+
+new GithubActionsSecretOrganization(scope, "GithubRepo", {
+  organizationName: "pepperize",
+  // 👇The name of the created GitHub secret
+  secretName: "example",
+  // 👇The source AWS SecretsManager secret and JSON field to use
+  source: GithubActionsSecret.fromSecretsManager(secret, "some-json-field"),
+  visibility: Visibility.ALL,
+  authOptions: AuthOptions.appAuth(auth),
+  // 👇Whether to delete or retain the GitHub secret on resource removal
+  removalPolicy: RemovalPolicy.DESTROY,
+});
+```
+
+See [GitHub Developer Guide](https://docs.github.com/de/rest/actions/secrets#create-or-update-an-organization-secret), [API Reference](https://github.com/pepperize/cdk-github/blob/main/API.md)
+
+### Repository Secret
+
+Manage an GitHib Actions Repository secret. Will fetch the source AWS SecretsManager secret and encrypt it to store in GitHub.
+
+```python
+// 👇The GitHub API authentication secret
+const auth = secrets_manager.Secret.fromSecretNameV2(scope, "Auth", "cdk-github/github-token");
+
+// 👇The AWS SecretsManager Secret to configure as GitHub Action secret.
+const secret = secrets_manager.Secret.fromSecretNameV2(scope, "Secret", "any-secret/example");
+
+new GithubActionsSecretRepository(scope, "GithubRepo", {
+  owner: "pepperize",
+  repositoryName: "cdk-github",
+  // 👇The name of the created GitHub secret
+  secretName: "example",
+  // 👇The source AWS SecretsManager secret and JSON field to use
+  source: GithubActionsSecret.fromSecretsManager(secret, "some-json-field"),
+  authOptions: AuthOptions.appAuth(auth),
+  // 👇Whether to delete or retain the GitHub secret on resource removal
+  removalPolicy: RemovalPolicy.DESTROY,
+});
+```
+
+See [GitHub Developer Guide](https://docs.github.com/de/rest/actions/secrets#create-or-update-a-repository-secret), [API Reference](https://github.com/pepperize/cdk-github/blob/main/API.md)
 '''
 import abc
 import builtins
@@ -388,84 +479,22 @@ class GithubApiCall:
         )
 
 
-class GithubCustomResource(
+class GithubCustomResourceBase(
     _constructs_77d1e7e8.Construct,
-    metaclass=jsii.JSIIMeta,
-    jsii_type="@pepperize/cdk-github.GithubCustomResource",
+    metaclass=jsii.JSIIAbstractClass,
+    jsii_type="@pepperize/cdk-github.GithubCustomResourceBase",
 ):
-    '''Example::
+    def __init__(self, scope: _constructs_77d1e7e8.Construct, id: builtins.str) -> None:
+        '''Creates a new construct node.
 
-    new GithubCustomResource(scope, "GithubRepo", {
-    onCreate: {
-    // https://octokit.github.io/rest.js/v19/#repos-create-in-org
-    endpoint: "repos",
-    method: "createInOrg",
-    parameters: {
-    org: "pepperize",
-    name: "cdk-github",
-    },
-    outputPaths: ["id", "full_name"],
-    physicalResourceId: custom_resources.PhysicalResourceId.fromResponse("full_name"),
-    ignoreErrorCodesMatching: "name already exists on this account",
-    },
-    onUpdate: {
-    // https://octokit.github.io/rest.js/v19#repos-get
-    endpoint: "repos",
-    method: "get",
-    parameters: {
-    owner: "pepperize",
-    repo: "cdk-github",
-    },
-    outputPaths: ["id", "full_name"],
-    physicalResourceId: custom_resources.PhysicalResourceId.fromResponse("full_name"),
-    },
-    onDelete: {
-    // https://octokit.github.io/rest.js/v19#repos-delete
-    endpoint: "repos",
-    method: "delete",
-    parameters: {
-    owner: "pepperize",
-    repo: "cdk-github",
-    },
-    outputPaths: [],
-    },
-    authOptions: AuthOptions.appAuth(secret),
-    })::
-    '''
-
-    def __init__(
-        self,
-        scope: _constructs_77d1e7e8.Construct,
-        id: builtins.str,
-        *,
-        auth_options: "IAuthOptions",
-        on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
-        on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
-        on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
-        resource_type: typing.Optional[builtins.str] = None,
-    ) -> None:
-        '''
-        :param scope: -
-        :param id: -
-        :param auth_options: Currently, supports only GitHub App. Example:: const auth = { appId, privateKey }; const installationAuth = { appId, privateKey, installationId };
-        :param on_create: The GitHub Api call to make when the resource is created.
-        :param on_delete: The GitHub Api call to make when the resource is deleted.
-        :param on_update: The GitHub Api call to make when the resource is updated.
-        :param resource_type: Cloudformation Resource type.
+        :param scope: The scope in which to define this construct.
+        :param id: The scoped construct ID. Must be unique amongst siblings. If the ID includes a path separator (``/``), then it will be replaced by double dash ``--``.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__34ac3907b3892d527d8ed5ffbe6f3d09b02d1b1041cd1e29f5f4f7710a70cefa)
+            type_hints = typing.get_type_hints(_typecheckingstub__38438883b6b085826e161771a9672aa025f16f31a72598a6e4d0503624714f8f)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        props = GithubCustomResourceProps(
-            auth_options=auth_options,
-            on_create=on_create,
-            on_delete=on_delete,
-            on_update=on_update,
-            resource_type=resource_type,
-        )
-
-        jsii.create(self.__class__, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id])
 
     @jsii.member(jsii_name="getAtt")
     def get_att(self, attribute_name: builtins.str) -> _aws_cdk_ceddda9d.Reference:
@@ -482,7 +511,7 @@ class GithubCustomResource(
         use the convenience ``getAttString`` for string attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__d8325810a88873bf09eb989ddd0497b9ac3548fe3b018a03e606ef9ee2ba8669)
+            type_hints = typing.get_type_hints(_typecheckingstub__72c6a4166499a94ce64d65c0901a6567d898914b75553010caab35842cc2520b)
             check_type(argname="argument attribute_name", value=attribute_name, expected_type=type_hints["attribute_name"])
         return typing.cast(_aws_cdk_ceddda9d.Reference, jsii.invoke(self, "getAtt", [attribute_name]))
 
@@ -498,7 +527,7 @@ class GithubCustomResource(
         :return: a token for ``Fn::GetAtt`` encoded as a string.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(_typecheckingstub__f3048bbbb682877779122b1b60e30674d866852cd1cd0d63fb0a6eadc3ce39cf)
+            type_hints = typing.get_type_hints(_typecheckingstub__57bb1bee46251a71a269b3ef1b062cbd93554ae4926adf563184773409af6134)
             check_type(argname="argument attribute_name", value=attribute_name, expected_type=type_hints["attribute_name"])
         return typing.cast(builtins.str, jsii.invoke(self, "getAttString", [attribute_name]))
 
@@ -509,9 +538,60 @@ class GithubCustomResource(
         return typing.cast(builtins.str, jsii.get(self, "ref"))
 
 
+class _GithubCustomResourceBaseProxy(GithubCustomResourceBase):
+    pass
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
+typing.cast(typing.Any, GithubCustomResourceBase).__jsii_proxy_class__ = lambda : _GithubCustomResourceBaseProxy
+
+
+@jsii.data_type(
+    jsii_type="@pepperize/cdk-github.GithubCustomResourceOptions",
+    jsii_struct_bases=[],
+    name_mapping={"auth_options": "authOptions"},
+)
+class GithubCustomResourceOptions:
+    def __init__(self, *, auth_options: "IAuthOptions") -> None:
+        '''
+        :param auth_options: Currently, supports only GitHub App. Example:: const auth = { appId, privateKey }; const installationAuth = { appId, privateKey, installationId };
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3aebf76d03bfa0187418a2ffdf41e801ff3b577aa72220a25ec15acf1958430a)
+            check_type(argname="argument auth_options", value=auth_options, expected_type=type_hints["auth_options"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
+            "auth_options": auth_options,
+        }
+
+    @builtins.property
+    def auth_options(self) -> "IAuthOptions":
+        '''Currently, supports only GitHub App.
+
+        Example::
+
+           const auth = { appId, privateKey };
+           const installationAuth = { appId, privateKey, installationId };
+
+        :see: https://github.com/octokit/authentication-strategies.js/#github-app-or-installation-authentication
+        '''
+        result = self._values.get("auth_options")
+        assert result is not None, "Required property 'auth_options' is missing"
+        return typing.cast("IAuthOptions", result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "GithubCustomResourceOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@pepperize/cdk-github.GithubCustomResourceProps",
-    jsii_struct_bases=[],
+    jsii_struct_bases=[GithubCustomResourceOptions],
     name_mapping={
         "auth_options": "authOptions",
         "on_create": "onCreate",
@@ -520,7 +600,7 @@ class GithubCustomResource(
         "resource_type": "resourceType",
     },
 )
-class GithubCustomResourceProps:
+class GithubCustomResourceProps(GithubCustomResourceOptions):
     def __init__(
         self,
         *,
@@ -685,10 +765,92 @@ class _AuthOptionsProxy(AuthOptions):
 typing.cast(typing.Any, AuthOptions).__jsii_proxy_class__ = lambda : _AuthOptionsProxy
 
 
+class GithubCustomResource(
+    GithubCustomResourceBase,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@pepperize/cdk-github.GithubCustomResource",
+):
+    '''Example::
+
+    new GithubCustomResource(scope, "GithubRepo", {
+    onCreate: {
+    // https://octokit.github.io/rest.js/v19/#repos-create-in-org
+    endpoint: "repos",
+    method: "createInOrg",
+    parameters: {
+    org: "pepperize",
+    name: "cdk-github",
+    },
+    outputPaths: ["id", "full_name"],
+    physicalResourceId: custom_resources.PhysicalResourceId.fromResponse("full_name"),
+    ignoreErrorCodesMatching: "name already exists on this account",
+    },
+    onUpdate: {
+    // https://octokit.github.io/rest.js/v19#repos-get
+    endpoint: "repos",
+    method: "get",
+    parameters: {
+    owner: "pepperize",
+    repo: "cdk-github",
+    },
+    outputPaths: ["id", "full_name"],
+    physicalResourceId: custom_resources.PhysicalResourceId.fromResponse("full_name"),
+    },
+    onDelete: {
+    // https://octokit.github.io/rest.js/v19#repos-delete
+    endpoint: "repos",
+    method: "delete",
+    parameters: {
+    owner: "pepperize",
+    repo: "cdk-github",
+    },
+    outputPaths: [],
+    },
+    authOptions: AuthOptions.appAuth(auth),
+    })::
+    '''
+
+    def __init__(
+        self,
+        scope: _constructs_77d1e7e8.Construct,
+        id: builtins.str,
+        *,
+        on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+        on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+        on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+        resource_type: typing.Optional[builtins.str] = None,
+        auth_options: IAuthOptions,
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param on_create: The GitHub Api call to make when the resource is created.
+        :param on_delete: The GitHub Api call to make when the resource is deleted.
+        :param on_update: The GitHub Api call to make when the resource is updated.
+        :param resource_type: Cloudformation Resource type.
+        :param auth_options: Currently, supports only GitHub App. Example:: const auth = { appId, privateKey }; const installationAuth = { appId, privateKey, installationId };
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__34ac3907b3892d527d8ed5ffbe6f3d09b02d1b1041cd1e29f5f4f7710a70cefa)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        props = GithubCustomResourceProps(
+            on_create=on_create,
+            on_delete=on_delete,
+            on_update=on_update,
+            resource_type=resource_type,
+            auth_options=auth_options,
+        )
+
+        jsii.create(self.__class__, self, [scope, id, props])
+
+
 __all__ = [
     "AuthOptions",
     "GithubApiCall",
     "GithubCustomResource",
+    "GithubCustomResourceBase",
+    "GithubCustomResourceOptions",
     "GithubCustomResourceProps",
     "IAuthOptions",
 ]
@@ -707,27 +869,28 @@ def _typecheckingstub__c44a6ed82823e6106770483149fb381def9b614340cbdf2ee1f568994
     """Type checking stubs"""
     pass
 
-def _typecheckingstub__34ac3907b3892d527d8ed5ffbe6f3d09b02d1b1041cd1e29f5f4f7710a70cefa(
+def _typecheckingstub__38438883b6b085826e161771a9672aa025f16f31a72598a6e4d0503624714f8f(
     scope: _constructs_77d1e7e8.Construct,
     id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__72c6a4166499a94ce64d65c0901a6567d898914b75553010caab35842cc2520b(
+    attribute_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__57bb1bee46251a71a269b3ef1b062cbd93554ae4926adf563184773409af6134(
+    attribute_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3aebf76d03bfa0187418a2ffdf41e801ff3b577aa72220a25ec15acf1958430a(
     *,
     auth_options: IAuthOptions,
-    on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
-    on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
-    on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
-    resource_type: typing.Optional[builtins.str] = None,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__d8325810a88873bf09eb989ddd0497b9ac3548fe3b018a03e606ef9ee2ba8669(
-    attribute_name: builtins.str,
-) -> None:
-    """Type checking stubs"""
-    pass
-
-def _typecheckingstub__f3048bbbb682877779122b1b60e30674d866852cd1cd0d63fb0a6eadc3ce39cf(
-    attribute_name: builtins.str,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -754,3 +917,16 @@ def _typecheckingstub__9ba10bce7d2f7f9a64938fe085321969cb9b61af281c3967164498784
 ) -> None:
     """Type checking stubs"""
     pass
+
+def _typecheckingstub__34ac3907b3892d527d8ed5ffbe6f3d09b02d1b1041cd1e29f5f4f7710a70cefa(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    on_create: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_delete: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_update: typing.Optional[typing.Union[GithubApiCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    resource_type: typing.Optional[builtins.str] = None,
+    auth_options: IAuthOptions,
+) -> None:
+    """Type checking stubs"""
+    pass
